EDFlib for Python
=================

EDFlib for Python is a programming library to read/write EDF+ (16-bit) and BDF+ (24-bit) files, written in pure Python.

For more info visit: https://www.teuniz.net/edflib_python/

No merge/pull requests. If you want to report a bug, create an issue.

License: 3-clause BSD license.

Have a look at test_edfreader.py and test_edfwriter.py, they demonstrate how to use the library.
You can find them here: https://gitlab.com/Teuniz/EDFlib-Python/-/tree/master/examples

You can generate documentation in HTML format by using the command: pydoc3 -w ./edfreader.py ./edfwriter.py

